@@ -945,6 +945,10 @@ fn test_range() {
     assert_eq!(d[0], 1.);
     assert_eq!(d[10], 2.);
     assert_eq!(d[12], 2.2);
+
+    let e = Array::range(1., 1., 1.);
+    assert_eq!(e.len(), 0);
+    assert!(e.is_empty());
 }
 
 #[test]
@@ -1170,6 +1174,8 @@ fn array_macros() {
     assert_eq!(a2, arr2(&[[1, 2], [3, 4], [5, 6]]));
     let a3 = array![[[1, 2], [3, 4]], [[5, 6], [7, 8]]];
     assert_eq!(a3, arr3(&[[[1, 2], [3, 4]], [[5, 6], [7, 8]]]));
+    let a4 = array![[[1, 2,], [3, 4,]], [[5, 6,], [7, 8,],],]; // trailing commas
+    assert_eq!(a4, arr3(&[[[1, 2], [3, 4]], [[5, 6], [7, 8]]]));
 
     let s = String::from("abc");
     let a2s = array![[String::from("w"), s],
